# Melid

Melid is a PyQt5 Library for Desktop Applications containing commonly used utils and advanced widget implementations in very simple forms.

# Features

- [x] Router
- [x] State management
- [x] Data binded widgets (Provider Widget)
- [ ] Hot-reload
- [x] CSS Processor (TailwindCSS Syntax)

# Install

```sh
$ pip install melid
```

# Usage

Check the examples folder for usage examples.

```sh
$ git clone https://github.com/dev-47/melid.git
$ cd melid/examples/basic
$ python main.py
```
